import Vue from 'vue';
import Router from 'vue-router';

Vue.use(Router);

const router = new Router({
	routes: [
		{
			path: '/',
			redirect: '/need/cache'
		},
		{
			path: '/',
			component: resolve => require(['../components/common/home.vue'], resolve),
			meta: {
				title: '自述文件'
			},
			children: [{
					path: '/personal',
					component: resolve => require(['../views/personal/index.vue'], resolve),
					meta: {
						title: '我的',
						tabberShow: true
					}
				},
				{
					path: '/setting',
					component: resolve => require(['../views/personal/setting/index.vue'], resolve),
					meta: {
						title: '账号信息',
						tabberShow: false
					}
				},
				{
					path: '/setName',
					component: resolve => require(['../views/personal/setting/name.vue'], resolve),
					meta: {
						title: '设置昵称',
						tabberShow: false
					}
				},
				{
					path: '/setSex',
					component: resolve => require(['../views/personal/setting/sex.vue'], resolve),
					meta: {
						title: '设置性别',
						tabberShow: false
					}
				},
				{	
					//参数my用于判定入口,从个人中心进入my==1
					path: '/recAddr/:my',
					component: resolve => require(['../views/personal/addr/recAddr.vue'], resolve),
					name:"recAddr",
					meta: {
						title: '收货地址',
						tabberShow: false
					}
				},
				{
					path: '/newAddr',
					component: resolve => require(['../views/personal/addr/newAddr.vue'], resolve),
					meta: {
						title: '新建收货地址',
						tabberShow: false
					}
				},
				{
					path: '/record',
					component: resolve => require(['../views/personal/record/index.vue'], resolve),
					meta: {
						title: '备案信息',
						tabberShow: false
					}
				},
				{
					path: '/examine',
					component: resolve => require(['../views/personal/record/examine.vue'], resolve),
					meta: {
						title: '备案信息',
						tabberShow: false
					}
				},
				{	
					path: '/order',
					component: resolve => require(['../views/order/index.vue'], resolve),
					name:"order",
					meta: {
						title: '订单',
						tabberShow: true
					}
				},
				{
					path: '/desc',
					component: resolve => require(['../views/order/desc.vue'], resolve),
					meta: {
						title: '订单详情',
						tabberShow: false
					}
				},
				{
					path: '/logistics',
					component: resolve => require(['../views/order/logistics.vue'], resolve),
					meta: {
						title: '物流信息',
						tabberShow: false
					}
				},
				{
					path: '/need/cache',
					component: resolve => require(['../views/need/cache.vue'], resolve),
					meta: {
						title: '采购需求',
						tabberShow: true
					}
				},
				{
					path: '/need/put',
					component: resolve => require(['../views/need/put.vue'], resolve),
					meta: {
						title: '立即备案',
						tabberShow: false
					}
				},
				{
					path: '/goodsList',
					component: resolve => require(['../views/goods/list.vue'], resolve),
					meta: {
						title: '新鲜蔬菜',
						tabberShow: false
					}
				},
				{
					path: '/goodsPrice',
					component: resolve => require(['../views/goods/price.vue'], resolve),
					meta: {
						title: '需求报价',
						tabberShow: false
					}
				},
				{
					path: '/pay',
					component: resolve => require(['../views/goods/pay.vue'], resolve),
					meta: {
						title: '确认订单',
						tabberShow: false
					}
				},
				{
					path: '/paySuccess',
					component: resolve => require(['../views/goods/paySuccess.vue'], resolve),
					meta: {
						title: '下单成功',
						tabberShow: false
					}
				},
				{
					path: '/shop',
					component: resolve => require(['../views/shop/index.vue'], resolve),
					meta: {
						title: '店铺首页',
						tabberShow: false
					}
				},
				{
					path: '/attention',
					component: resolve => require(['../views/shop/attention.vue'], resolve),
					meta: {
						title: '关注的店铺',
						tabberShow: false
					}
				},
				{
					path: '/shop/desc',
					component: resolve => require(['../views/shop/desc.vue'], resolve),
					meta: {
						title: '商品详情',
						tabberShow: false
					}
				},
				{
					path: '/bill',
					component: resolve => require(['../views/bill/index.vue'], resolve),
					meta: {
						title: '常买清单',
						tabberShow: true
					}
				},
			]
		},
		{
			path: '/login',
			component: resolve => require(['../views/login.vue'], resolve),
			name:'login'
		}
	]
});

router.beforeEach((to, form, next) => {
	if (to.meta.title) {
		document.title = to.meta.title
	}
	next();
});

export default router;
