import request from '@/utils/request'
import moment from 'moment'
import noImgUrl from '@/assets/img/no_data.png';

var indexMixin = {
	data() {
		return {
			priceObj:{},
			showShopcart: false,
			showProductDesc: false,
			spinner1: 3,
			spinner2: 3,
			pageNum: 0,
			isActive: '0',
			maxAmount: 1,
			//获取报价列表请求参数
			priceParams: {
				pageNum: 1,
				pageSize: 100000,
				ids: [],
				buyerId: this.Cookies.get('buyerId')
			},
			list: [],
			desc: {
				orderAmount: 1,
				price: '',
				amount: 1,
				specification: ''
			},
			totalMoney: 0,
			defaultImg: 'this.src="' + require('@/assets/img/default.png') + '"',
			totalPricce: '',
			univalent: '',
			orderList: [],
			Urls: {
				listUrl: '/product/findProductByIds',
				descUrl: '/sellerProduct/findProductById',
				morePriceUrl: '/sellerProduct/productType',
				delCacheUrl: '/product/quoteCache',
				addCacheUrl: '/product/quoteCache'
			},
			noImgUrl: noImgUrl,
			moreList: [],
			moreTotal: 0,
			oldShow: false
		};
	},
	mounted() {
		this.getShopcart();
		//取得最新报价
		this.getList();
	},
	created() {},
	//销毁和离开当前页面触发
	destroyed() {
		//是否已经选择报价显示控制
		this.list = this.list.map((v,x) => {
			v.productId = v.id;
			v.checked = false;
			for (let j = 0; j < this.orderList.length; j++) {
				if (this.orderList[j].productId == v.id) {
					v.checked = true;
					break;
				}
			}
			return v;
		});
		this.delCache(r=>{
			this.addCache();
		});
	},
	watch: {
		//监听列表变化
		orderList(newVal) {
			let sum = 0;
			for (let i = 0; i < newVal.length; i++) {
				if (!newVal[i].amount) {
					this.$set(newVal[i], 'amount', 1);
				}
				newVal[i].orderAmount = (
					(Number(newVal[i].specPrice) || 0) * Number(newVal[i].amount || 1)
				).toFixed(2);
				sum += (Number(newVal[i].specPrice) || 0) * Number(newVal[i].amount || 1);
			}
			this.totalMoney = sum.toFixed(2);
		}
	},
	methods: {
		back() {
			window.addEventListener('popstate', (e) => {
				this.$router.push('/need/cache');
			}, false);
		},
		//删除缓存
		delCache(fun) {
			let cT = this.priceObj.createTime || '';
			request({
				url: this.Urls.delCacheUrl,
				method: 'delete',
				params: {
					equipment: "H5",
					userId: this.buyerId,
					createTime: cT
				}
			}).then(response => {
				if (response.data.retHead.errCode == 0) {
					fun && fun();
				} else {
					this.$dialog.toast({
						mes: response.data.retHead.errMsg,
						icon: 'error',
						timeout: 1500
					});
				}
			});
		},
		//新增缓存
		addCache() {
			this.priceObj.createTime = this.moment().format('YYYY-MM-DD HH:mm:ss');
			this.priceObj.price = this.orderList;
			this.priceObj.unPrice = this.list;
			this.priceObj.endTime = '';
			this.$session.set("priceObj",this.priceObj);
			request({
				url: this.Urls.addCacheUrl,
				method: 'post',
				params: {
					equipment: "H5",
					userId: this.buyerId,
					createTime: this.priceObj.createTime
				},
				data: this.priceObj
			}).then(response => {
				if (response.data.retHead.errCode == 0) {
					//更新缓存显示列表
					this.$root.$emit('cacheList',res=>{
						res.routerList && res.routerList.loadList && res.routerList.loadList();
					});
				} else {
					this.$dialog.toast({
						mes: response.data.retHead.errMsg,
						icon: 'error',
						timeout: 1500
					});
				}
			});
		},
		//获取最新报价
		getList() {
			this.$dialog.loading.open('正在获取报价');
			let data = this.priceParams;
			request({
				url: this.Urls.listUrl,
				method: 'post',
				data
			}).then(response => {
				this.$dialog.loading.close();
				if (response.data.retHead.errCode == 0) {
					this.list = response.data.retBody.list;
					//深合并数组
					this.list = this.list.map((i,x)=>{
						return Object.assign(this.list[x] || {},i);
					});
				} else {
					this.$dialog.toast({
						mes: response.data.retHead.errMsg,
						icon: 'error',
						timeout: 1500
					});
				}
			});
		},
		//获取当前报价缓存
		getShopcart() {
			//取得报价对象
			this.priceObj = this.$session.get('priceObj');
			//回填入购物车
			this.orderList = this.priceObj.price || [];
			//获取id数组用于获取报价
			this.priceParams.ids = this.priceObj.keys || [];
			//按checked false排序
			let _list = this.priceObj.unPrice || [];
			for (let i = 0; i < _list.length; i++) {
				let it = _list.splice(i, 1)[0];
				//如果当前比对基数为true 向后插入  false向前插入
				it.checked ? _list.push(it) : _list.unshift(it);
			}
			this.list = _list;
		},
		//查看更多
		getMore(index) {
			let obj = this.list[index];
			obj.moreList = obj.moreList || [];
			this.$dialog.loading.open('正在加载');
			let data = {
				pageNum: obj.pageNum + 1,
				pageSize: 5,
				productId: obj.id,
				buyerId: this.buyerId
			};
			request({
				url: this.Urls.morePriceUrl,
				method: 'post',
				data
			}).then(response => {
				this.$dialog.loading.close();
				if (response.data.retHead.errCode == 0) {
					obj.moreTotal = response.data.retBody.total;
					obj.moreList = obj.moreList.concat(
						response.data.retBody.list
					);
					obj.pageNum++;
					this.list.splice(index,1,obj);
				} else {
					this.$dialog.toast({
						mes: response.data.retHead.errMsg,
						icon: 'error',
						timeout: 1500
					});
				}
			});
		},
		//选择商品弹框
		getDesc(item) {
			this.showProductDesc = true;
			this.$dialog.loading.open('正在加载');
			request({
				url: this.Urls.descUrl,
				method: 'get',
				params: {
					id: item.id
				}
			}).then(response => {
				this.$dialog.loading.close();
				if (response.data.retHead.errCode == 0) {
					this.desc = response.data.retBody;
					this.desc.sellerId = item.sellerId;
					this.getPrice(
						this.desc.sellerProductSpecs[0].specification,
						this.desc.sellerProductSpecs[0].price,
						0,
						this.desc.sellerProductSpecs[0].id,
						this.desc.sellerProductSpecs[0].inventory
					);
				} else {
					this.$dialog.toast({
						mes: response.data.retHead.errMsg,
						icon: 'error',
						timeout: 1500
					});
				}
			});
		},
		//当前商品
		getPrice(spec, price, index, id, max) {
			this.isActive = index;
			this.desc.specPrice = price.toFixed(2);
			this.desc.price = (price / spec).toFixed(2);
			this.desc.specification = spec;
			this.desc.sellerProductSpecId = id;
			this.desc.maxAmount = max;
		},
		//选择当前商品
		addShopcart() {
			this.showProductDesc = false;
			for (let i = 0; i < this.orderList.length; i++) {
				if (this.orderList[i].id == this.desc.id && this.orderList[i].specification == this.desc.specification) {
					let n = Number(this.orderList[i].amount || 1) + Number(this.desc.amount || 1);
					this.orderList[i].amount = n >= this.desc.maxAmount ? this.desc.maxAmount : n;
					return;
				}
			}
			for(let i = 0;i < this.orderList.length;i++){
				let o = this.orderList[i];
				o.productId == this.desc.productId && this.orderList.splice(i,1);
			}
			this.orderList.push(this.desc);
		},
		//清空购物车
		clearShopcart() {
			this.$dialog.confirm({
				title: '清空购物车',
				mes: '您确定要清空吗！！！',
				opts: () => {
					this.orderList = [];
					this.totalMoney = 0;
				}
			});
		},
		// 删除购物车商品
		delShopCart(index) {
			this.$dialog.confirm({
				title: '删除商品',
				mes: '您确定要删除吗！！！',
				opts: () => {
					this.orderList.splice(index, 1);
				}
			});
		},
		//购物车里面的数量加减
		spinnerCall(val, num) {
			let sum = 0;
			for (let i = 0; i < this.orderList.length; i++) {
				this.orderList[i].orderAmount = (
					Number(this.orderList[i].specPrice) * Number(this.orderList[i].amount || 1)
				).toFixed(2);
				sum += Number(this.orderList[i].specPrice) * Number(this.orderList[i].amount);
			}
			this.totalMoney = sum.toFixed(2);
		},
		//去结算
		goPay() {
			if (this.orderList.length == 0) {
				this.$dialog.toast({
					mes: '请选择你要结算的商品',
					icon: 'none',
					timeout: 1500
				});
				return;
			}
			this.flowList = this.orderList.map((d, i) => {
				return {
					amount: d.amount || 1,
					orderAmount: d.orderAmount,
					sellerProductId: d.id,
					price: d.specPrice,
					productImgUrl: d.imgUrl,
					productName: d.goodsName,
					sellerId: d.sellerId,
					sellerName: d.sellerName,
					specification: d.specification,
					sellerProductSpecId: d.sellerProductSpecId,
					specPrice: d.specPrice,
					productId:d.productId
				};
			});
			//合并相同商品
			//let listData = [];
			// (function t(data) {
			// 	let obj = data.shift();
			// 	for (let i = 0; i < data.length;) {
			// 		if (obj.id == data[i].id && obj.specification == data[i].specification) {
			// 			obj.amount += Number(data[i].amount || 0);
			// 			data.splice(i, 1);
			// 		} else {
			// 			i++;
			// 		}
			// 	}
			// 	listData.push(JSON.parse(JSON.stringify(obj)));
			// 	data.length && t(data);
			// })(this.flowList);

			//检测是否全部选择报价
			let num = [],_num = this.list.length;
			for(let i = 0;i < this.list.length;i++){
				let it = this.list[i];
				if(it.lowestQuotation || it.recentlyQuotation || it.collectQuotation || it.moreList && it.moreList.length){
					for(let i = 0;i < this.flowList.length;i++){
						let il = this.flowList[i];
						if(it.id == il.productId){
							num.push(it.id);
						}
					}
				}else{
					_num--;
				}
			}
			let vb = g => {
				this.Cookies.set('orderList', JSON.stringify(this.flowList));
				this.$router.push('/pay');
			};
			!(Array.from(new Set(num)).length == _num) ? this.$dialog.confirm({
				title: '获取报价',
				mes: '您有商品未选择报价，是否进行结算？',
				opts: () => {
					vb(0);
				}
			}) : vb(0);
		}
	}
};

export default indexMixin;
